Augmentation
--------------------


Augmentation is an important tool for getting more out of your tagged data by allowing
you to introduce non-meaningful variation into a text. This can for instance include
replacing a name with a another name or adding spelling errors.

Augmentation can also be used for estimating how robust a model is to e.g. spelling
errors or casing, or how biases a model is  by e.g. replacing male names with female
names. For Danish models we examine this further under
`Robustness and biases <https://centre-for-humanities-computing.github.io/DaCy/robustness.html>`__.



.. seealso::

    DaCy augmenters now have a new home. They are now included in 
    `augmenty <https://github.com/kennethenevoldsen/augmenty>`__. Augmenty offers
    a wider range of augmenters and is jointly developed with DaCy. For a guide on how
    to use Augmenty check out their
    `getting started guide <https://kennethenevoldsen.github.io/augmenty/tutorials/introduction.html>`__


